#ifndef __BSP_H__
#define __BSP_H__

#include <ubb/ubb.h>
#include "EPD.h"

/* Pin assignments:
 *
 * Sniffer  UBB   EM027AS012
 * -------  ----  -----------
 * DAT2     DAT2   4 (MOSI)
 * CD       DAT3   6 (SSEL)
 * CMD      CMD   11 (PWM)
 * VCC      VDD   13 (PANEL)
 * CLK      CLK    3 (SCK)
 * GND      GND
 * DAT0     DAT0  12 (RESET)
 * DAT1     DAT1  14 (DIS)
 *
 * General connections:
 *
 *                EM027AS012
 *                ----------
 *                 1 (GND)
 *                 2 (3V3)
 */

#define EPD_MOSI  UBB_DAT2
#define EPD_SSEL  UBB_DAT3
#define EPD_PWM   UBB_CMD
#define EPD_SCK   UBB_CLK
#define EPD_RESET UBB_DAT0
#define EPD_DIS   UBB_DAT1

/* Board-specific interface functions. */

void EPD_Pin_init();
void EPD_Pin_EPD_CS(EPD_pinstate pin);
void EPD_Pin_RESET(EPD_pinstate pin);
void EPD_Pin_PANEL_ON(EPD_pinstate pin);
void EPD_Pin_DISCHARGE(EPD_pinstate pin);
void EPD_Pin_BORDER(EPD_pinstate pin);
void EPD_Pin_PWM(EPD_pinstate pin);
EPD_pinstate epd_get_busy();

void bsp_spiWrite(uint8_t *buffer, uint16_t length);
void bsp_delayMs(uint32_t ms);
void bsp_delayUs(uint32_t us);
uint32_t bsp_getMsTicks();
uint32_t bsp_getUsTicks();
int16_t bsp_getTemp();

#endif /* __BSP_H__ */
