/*
 * Ben NanoNote and EM027AS012 E-Paper Display Adapter Board communication.
 *
 * Copyright (C) 2013 Paul Boddie
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#include <ubb/ubb.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <signal.h>
#include "logo.h"
#include "EPD.h"
#include "bsp.h"

static uint8_t old_image[264 * 176 / 8],
               new_image[264 * 176 / 8];

/**
 * Handle termination of the process.
 */
void shutdown(int signum)
{
    printf("Closing...\n");
    ubb_close(0);
    exit(1);
}

/* Main program and basic initialisation. */

int main(int argc, char *argv[])
{
    signal(SIGINT, &shutdown);

    if (ubb_open(0) < 0) {
        perror("ubb_open");
        return 1;
    }

    /* Need to initialise the board. */

    EPD_init(EPD_2_7);
    printf("Initialised.\n");

    /* Initialise an array containing the current image. */

    memset(old_image, 0, sizeof(old_image));
    /* memset(new_image, 0, sizeof(new_image)); */
    memcpy(new_image, (uint8_t *) image_data[0], sizeof(new_image));

    printf("Clear image.\n");

    EPD_begin();
    EPD_setFactor(bsp_getTemp());
    EPD_clear();
    EPD_end();

    printf("Set image.\n");

    EPD_begin();
    EPD_setFactor(bsp_getTemp());
    EPD_image_change(old_image, new_image);
    EPD_end();

    /* memcpy(old_image, new_image, sizeof(old_image)); */

    printf("Closing...\n");
    ubb_close(0);

    return 0;
}
